betty.copyright_notice.copyright_notices module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.copyright_notice.copyright_notices module

Provide `betty.copyright_notice.CopyrightNotice` plugins.

class betty.copyright_notice.copyright_notices.ProjectAuthor

  Bases: `ShorthandPluginBase`, `ProjectDependentFactory`, `CopyrightNotice`

  Copyright belonging to a project author.

  __init__(author: Localizable | None)
  async classmethod new_for_project(project: Project) → Self

    Create a new instance using the given project.

  property summary: Localizable

    The copyright summary.

  property text: Localizable

    The full copyright text.

class betty.copyright_notice.copyright_notices.PublicDomain

  Bases: `ShorthandPluginBase`, `CopyrightNotice`

  A work is in the public domain <https://en.wikipedia.org/wiki/Public_domain>.

  property summary: Localizable

    The copyright summary.

  property text: Localizable

    The full copyright text.